@@ -9,8 +9,9 @@ https://docs.djangoproject.com/en/3.0/howto/deployment/wsgi/
 
 import os
 
-from django.core.wsgi import get_wsgi_application
-
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'corgy_erp.settings')
+os.environ.setdefault('DJANGO_CONFIGURATION', 'Production')
+
+from configurations.wsgi import get_wsgi_application
 
 application = get_wsgi_application()
